﻿using Microsoft.Win32;
using System;
using System.Globalization;
using System.IO;
using System.Linq;
using System.Windows;

namespace WpfApp
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        string Key = "<License>\r\n  <ExpirationDate>2026-01-22T23:59:59</ExpirationDate>\r\n  <ID>TRIAL</ID>\r\n  <Modules>\r\n    <string>5AXIS</string>\r\n  </Modules>\r\n  <Signature>6uBT+1dMf2ExKenHUMT7FmycbGbh2KffJ1xR1l9Mxi/q1qrb7kWxu5Kd9Gv8U7yE6TfqkXFzpQy98R2BZn0x/ROwaRXdo2QKKe0wK57mo5EjkQhOXroCPaRSJr10hK+mBnm31KfK6WthZgmeMLkkJaKvGaDlad6y06acbOjXcck=</Signature>\r\n</License>";

        double x = 0.0;
        double y = 0.0;
        double z = 0.0;
        double rot1 = 0.0;
        double rot2 = 0.0;
        int tool = -1;

        public MainWindow()
        {
            InitializeComponent();
            ncView.Start(Key);

            comboBox.SelectedIndex = 0;
        }

        private void import_Click(object sender, RoutedEventArgs e)
        {
            OpenFileDialog dialog = new OpenFileDialog();
            if (dialog.ShowDialog() == true)
            {
                textBox.Text = string.Join(Environment.NewLine, File.ReadLines(dialog.FileName).ToList());
                ncView.LoadFile(textBox.Text);
            }
        }

        private void ncView_FileLoaded(object sender, EventArgs e)
        {
            slider.Maximum = ncView.JobMaxId;
        }

        private void reprocess_Click(object sender, RoutedEventArgs e)
        {
            ncView.LoadFile(textBox.Text);
        }

        private void addStl_Click(object sender, EventArgs e)
        {
            OpenFileDialog dialog = new OpenFileDialog();
            dialog.Filter = "stl|*.stl";
            if (dialog.ShowDialog() == true)
            {
                ncView.LoadPart(dialog.FileName);
            }
        }

        private void clearStl_Click(object sender, EventArgs e)
        {
            ncView.ClearParts();
        }

        private void play_Click(object sender, RoutedEventArgs e)
        {
            ncView.PauseSimulation();
            double speed = speedSlider.Value / 100;
            ncView.PlaySimulation(speed);
        }


        private void ncView_SelectionChanged(object source, NCneticLib.ncView.SelectionChangedEventArgs e)
        {
            Application.Current.Dispatcher.Invoke(() =>
            {
                x = (double)ncView.GetValue(NCneticLib.ncView.ValueType.TARGET_X);
                y = (double)ncView.GetValue(NCneticLib.ncView.ValueType.TARGET_Y);
                z = (double)ncView.GetValue(NCneticLib.ncView.ValueType.TARGET_Z);
                rot1 = (double)ncView.GetValue(NCneticLib.ncView.ValueType.TARGET_ROT1);
                rot2 = (double)ncView.GetValue(NCneticLib.ncView.ValueType.TARGET_ROT2);
                tool = (int)ncView.GetValue(NCneticLib.ncView.ValueType.TOOL_NUMBER);

                xLabel.Content = "X=" + x.ToString("0.000", CultureInfo.InvariantCulture);
                yLabel.Content = "Y=" + y.ToString("0.000", CultureInfo.InvariantCulture);
                zLabel.Content = "Z=" + z.ToString("0.000", CultureInfo.InvariantCulture);
                rot1Label.Content = "ROT1=" + rot1.ToString("0.000", CultureInfo.InvariantCulture);
                rot2Label.Content = "ROT2=" + rot2.ToString("0.000", CultureInfo.InvariantCulture);

                if (e.Id >= 0 && e.Id != slider.Value)
                {
                    slider.Value = e.Id;
                }
                if (e.Line >= 0 && e.Line != textBox.GetLineIndexFromCharacterIndex(textBox.CaretIndex))
                {
                    textBox.CaretIndex = textBox.GetCharacterIndexFromLineIndex(e.Line);
                    textBox.ScrollToLine(e.Line);
                }
            });
        }

        private void slider_ValueChanged(object sender, EventArgs e)
        {
            ncView.GotoId((int)slider.Value);
        }

        private void textBox_SelectionChanged(object sender, EventArgs e)
        {
            ncView.GotoLine(textBox.GetLineIndexFromCharacterIndex(textBox.CaretIndex));
        }

        private void comboBox_SelectionChanged(object sender, EventArgs e)
        {
            ncView.LoadFile(string.Empty);
            ncView.ClearParts();

            ncView.LoadToolDB("TOOL_DB.xml");

            switch (comboBox.SelectedIndex)
            {
                case 0:
                    ncView.LoadMachine("3A.xml");
                    ncView.LoadPart("3A.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("3A.nc"));
                    break;
                case 1:
                    ncView.LoadMachine("4A_A.xml");
                    ncView.LoadPart("4A_A.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("4A_A.nc"));
                    break;
                case 2:
                    ncView.LoadMachine("4A_B.xml");
                    ncView.LoadPart("4A_B.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("4A_B.nc"));
                    break;
                case 3:
                    ncView.LoadMachine("4AH_A.xml");
                    ncView.LoadPart("4AH_A.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("4AH_A.nc"));
                    break;
                case 4:
                    ncView.LoadMachine("4AH_B.xml");
                    ncView.LoadPart("4AH_B.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("4AH_B.nc"));
                    break;
                case 5:
                    ncView.LoadMachine("5A_AC.xml");
                    ncView.LoadPart("5A.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("5A_AC.nc"));
                    break;
                case 6:
                    ncView.LoadMachine("5A_BC.xml");
                    ncView.LoadPart("5A.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("5A_BC.nc"));
                    break;
                case 7:
                    ncView.LoadMachine("5AH_AB.xml");
                    ncView.LoadPart("5A.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("5AH_AB.nc"));
                    break;
                case 8:
                    ncView.LoadMachine("5AH_BA.xml");
                    ncView.LoadPart("5A.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("5AH_BA.nc"));
                    break;
                case 9:
                    ncView.LoadMachine("5AH_AC.xml");
                    ncView.LoadPart("5A.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("5AH_AC.nc"));
                    break;
                case 10:
                    ncView.LoadMachine("5AH_BC.xml");
                    ncView.LoadPart("5A.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("5AH_BC.nc"));
                    break;
                case 11:
                    ncView.LoadMachine("5AHH_AB.xml");
                    ncView.LoadPart("5A.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("5AHH_AB.nc"));
                    break;
                case 12:
                    ncView.LoadMachine("5AHH_BA.xml");
                    ncView.LoadPart("5A.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("5AHH_BA.nc"));
                    break;
                case 13:
                    ncView.LoadMachine("5AHH_AC.xml");
                    ncView.LoadPart("5A.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("5AHH_AC.nc"));
                    break;
                case 14:
                    ncView.LoadMachine("5AHH_BC.xml");
                    ncView.LoadPart("5A.stl");
                    textBox.Text = string.Join("\r\n", File.ReadLines("5AHH_BC.nc"));
                    break;
            }

            ncView.LoadFile(textBox.Text);
        }

        private void xm_Click(object sender, EventArgs e)
        {
            x -= 10;
            ncView.SetPosition(x, y, z, rot1, rot2, tool);
        }

        private void xp_Click(object sender, EventArgs e)
        {
            x += 10;
            ncView.SetPosition(x, y, z, rot1, rot2, tool);
        }

        private void ym_Click(object sender, EventArgs e)
        {
            y -= 10;
            ncView.SetPosition(x, y, z, rot1, rot2, tool);
        }

        private void yp_Click(object sender, EventArgs e)
        {
            y += 10;
            ncView.SetPosition(x, y, z, rot1, rot2, tool);
        }

        private void zm_Click(object sender, EventArgs e)
        {
            z -= 10;
            ncView.SetPosition(x, y, z, rot1, rot2, tool);
        }

        private void zp_Click(object sender, EventArgs e)
        {
            z += 10;
            ncView.SetPosition(x, y, z, rot1, rot2, tool);
        }

        private void r1m_Click(object sender, EventArgs e)
        {
            rot1 -= 0.1;
            ncView.SetPosition(x, y, z, rot1, rot2, tool);
        }

        private void r1p_Click(object sender, EventArgs e)
        {
            rot1 += 0.1;
            ncView.SetPosition(x, y, z, rot1, rot2, tool);
        }

        private void r2m_Click(object sender, EventArgs e)
        {
            rot2 -= 0.1;
            ncView.SetPosition(x, y, z, rot1, rot2, tool);
        }

        private void r2p_Click(object sender, EventArgs e)
        {
            rot2 += 0.1;
            ncView.SetPosition(x, y, z, rot1, rot2, tool);
        }
    }
}
